@@ -9,13 +9,13 @@ from dagster_graphql.client.query import RAW_EXECUTE_PLAN_MUTATION
 from dagster_graphql.client.util import construct_execute_plan_variables, parse_raw_log_lines
 
 from dagster import __version__ as dagster_version
-from dagster import seven
+from dagster import check, seven
 from dagster.core.events import EngineEventData
-from dagster.core.instance import DagsterInstance
+from dagster.core.instance import AIRFLOW_EXECUTION_DATE_STR, DagsterInstance
 from dagster.utils.error import serializable_error_info_from_exc_info
 
 from .util import (
-    add_airflow_tags,
+    airflow_tags_for_ts,
     check_events_for_failures,
     check_events_for_skips,
     get_aws_environment,
@@ -27,10 +27,10 @@ LOG_RETRIEVAL_WAITS_BETWEEN_ATTEMPTS_SEC = 5
 
 
 class DagsterKubernetesPodOperator(KubernetesPodOperator):
-    '''Dagster operator for Apache Airflow.
+    """Dagster operator for Apache Airflow.
 
     Wraps a modified KubernetesPodOperator.
-    '''
+    """
 
     # py2 compat
     # pylint: disable=keyword-arg-before-vararg
@@ -40,10 +40,10 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
         self.pipeline_snapshot = operator_parameters.pipeline_snapshot
         self.execution_plan_snapshot = operator_parameters.execution_plan_snapshot
         self.parent_pipeline_snapshot = operator_parameters.parent_pipeline_snapshot
-        kwargs['name'] = 'dagster.{pipeline_name}.{task_id}'.format(
+        kwargs["name"] = "dagster.{pipeline_name}.{task_id}".format(
             pipeline_name=self.pipeline_name, task_id=operator_parameters.task_id
         ).replace(
-            '_', '-'  # underscores are not permissible DNS names
+            "_", "-"  # underscores are not permissible DNS names
         )
 
         self.run_config = operator_parameters.run_config
@@ -59,30 +59,27 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
             else None
         )
 
-        # Store Airflow DAG run timestamp so that we can pass along via execution metadata
-        self.airflow_ts = kwargs.get('ts')
-
         # Add AWS creds
-        self.env_vars = kwargs.get('env_vars', {})
+        self.env_vars = kwargs.get("env_vars", {})
         for k, v in get_aws_environment().items():
             self.env_vars.setdefault(k, v)
 
-        kwargs.setdefault('labels', {})
-        kwargs['labels'].setdefault('dagster_pipeline', self.pipeline_name)
-        kwargs['labels'].setdefault('app.kubernetes.io/name', 'dagster')
-        kwargs['labels'].setdefault('app.kubernetes.io/instance', self.pipeline_name)
-        kwargs['labels'].setdefault('app.kubernetes.io/version', dagster_version)
-        kwargs['labels'].setdefault('app.kubernetes.io/component', 'pipeline-execution')
-        kwargs['labels'].setdefault('app.kubernetes.io/part-of', 'dagster-airflow')
-        kwargs['labels'].setdefault('app.kubernetes.io/managed-by', 'dagster-airflow')
+        kwargs.setdefault("labels", {})
+        kwargs["labels"].setdefault("dagster_pipeline", self.pipeline_name)
+        kwargs["labels"].setdefault("app.kubernetes.io/name", "dagster")
+        kwargs["labels"].setdefault("app.kubernetes.io/instance", self.pipeline_name)
+        kwargs["labels"].setdefault("app.kubernetes.io/version", dagster_version)
+        kwargs["labels"].setdefault("app.kubernetes.io/component", "pipeline-execution")
+        kwargs["labels"].setdefault("app.kubernetes.io/part-of", "dagster-airflow")
+        kwargs["labels"].setdefault("app.kubernetes.io/managed-by", "dagster-airflow")
 
         # The xcom mechanism for the pod operator is very unlike that of the Docker operator, so
         # we disable it
-        if 'xcom_push' in kwargs:
+        if "xcom_push" in kwargs:
             self.log.warning(
-                'xcom_push cannot be enabled with the DagsterKubernetesPodOperator, disabling'
+                "xcom_push cannot be enabled with the DagsterKubernetesPodOperator, disabling"
             )
-        kwargs['xcom_push'] = False
+        kwargs["xcom_push"] = False
 
         super(DagsterKubernetesPodOperator, self).__init__(
             task_id=operator_parameters.task_id, dag=operator_parameters.dag, *args, **kwargs
@@ -90,10 +87,11 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
 
     @property
     def run_id(self):
-        return getattr(self, '_run_id', '')
+        return getattr(self, "_run_id", "")
+
+    def query(self, airflow_ts):
+        check.opt_str_param(airflow_ts, "airflow_ts")
 
-    @property
-    def query(self):
         variables = construct_execute_plan_variables(
             self.recon_repo,
             self.mode,
@@ -102,20 +100,21 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
             self.run_id,
             self.step_keys,
         )
-        variables = add_airflow_tags(variables, self.airflow_ts)
+        tags = airflow_tags_for_ts(airflow_ts)
+        variables["executionParams"]["executionMetadata"]["tags"] = tags
 
         self.log.info(
-            'Executing GraphQL query: {query}\n'.format(query=RAW_EXECUTE_PLAN_MUTATION)
-            + 'with variables:\n'
+            "Executing GraphQL query: {query}\n".format(query=RAW_EXECUTE_PLAN_MUTATION)
+            + "with variables:\n"
             + seven.json.dumps(variables, indent=2)
         )
 
         return [
-            'dagster-graphql',
-            '-v',
-            '{}'.format(seven.json.dumps(variables)),
-            '-t',
-            '{}'.format(RAW_EXECUTE_PLAN_MUTATION),
+            "dagster-graphql",
+            "-v",
+            "{}".format(seven.json.dumps(variables)),
+            "-t",
+            "{}".format(RAW_EXECUTE_PLAN_MUTATION),
         ]
 
     def execute(self, context):
@@ -128,14 +127,14 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
 
         except ImportError:
             raise AirflowException(
-                'To use the DagsterKubernetesPodOperator, dagster and dagster_graphql must be'
-                ' installed in your Airflow environment.'
+                "To use the DagsterKubernetesPodOperator, dagster and dagster_graphql must be"
+                " installed in your Airflow environment."
             )
 
-        if 'run_id' in self.params:
-            self._run_id = self.params['run_id']
-        elif 'dag_run' in context and context['dag_run'] is not None:
-            self._run_id = context['dag_run'].run_id
+        if "run_id" in self.params:
+            self._run_id = self.params["run_id"]
+        elif "dag_run" in context and context["dag_run"] is not None:
+            self._run_id = context["dag_run"].run_id
 
         # return to original execute code:
         try:
@@ -156,7 +155,7 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
                 image=self.image,
                 pod_id=self.name,
                 cmds=self.cmds,
-                arguments=self.query,
+                arguments=self.query(context.get("ts")),
                 labels=self.labels,
             )
 
@@ -177,6 +176,10 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
             launcher = pod_launcher.PodLauncher(kube_client=client, extract_xcom=self.xcom_push)
             try:
                 if self.instance:
+                    tags = (
+                        {AIRFLOW_EXECUTION_DATE_STR: context.get("ts")} if "ts" in context else {}
+                    )
+
                     run = self.instance.register_managed_run(
                         pipeline_name=self.pipeline_name,
                         run_id=self.run_id,
@@ -184,7 +187,7 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
                         mode=self.mode,
                         solids_to_execute=None,
                         step_keys_to_execute=None,
-                        tags=None,
+                        tags=tags,
                         root_run_id=None,
                         parent_run_id=None,
                         pipeline_snapshot=self.pipeline_snapshot,
@@ -204,14 +207,14 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
                 num_attempts = 0
                 while not res and num_attempts < LOG_RETRIEVAL_MAX_ATTEMPTS:
                     raw_res = client.read_namespaced_pod_log(
-                        name=pod.name, namespace=pod.namespace, container='base'
+                        name=pod.name, namespace=pod.namespace, container="base"
                     )
-                    res = parse_raw_log_lines(raw_res.split('\n'))
+                    res = parse_raw_log_lines(raw_res.split("\n"))
                     time.sleep(LOG_RETRIEVAL_WAITS_BETWEEN_ATTEMPTS_SEC)
                     num_attempts += 1
 
                 try:
-                    handle_execution_errors(res, 'executePlan')
+                    handle_execution_errors(res, "executePlan")
                 except DagsterGraphQLClientError as err:
                     self.instance.report_engine_event(
                         str(err),
@@ -241,7 +244,7 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
                     launcher.delete_pod(pod)
 
             if final_state != State.SUCCESS:
-                raise AirflowException('Pod returned a failure: {state}'.format(state=final_state))
+                raise AirflowException("Pod returned a failure: {state}".format(state=final_state))
             # note the lack of returning the default xcom
         except AirflowException as ex:
-            raise AirflowException('Pod Launching failed: {error}'.format(error=ex))
+            raise AirflowException("Pod Launching failed: {error}".format(error=ex))
